@@ -19,6 +19,8 @@
 #include "protocols/wlr-foreign-toplevel-management-unstable-v1-client-protocol.h"
 #include "protocols/wlr-output-management-unstable-v1-client-protocol.h"
 
+#include <phosh-plugin.h>
+
 #include <gdk/wayland/gdkwayland.h>
 #include <wayland-client.h>
 #include <glib/gi18n.h>
@@ -385,6 +387,9 @@ mobile_settings_application_show_about (GSimpleAction *action,
                                                                       MOBILE_SETTINGS_VERSION));
   adw_about_window_set_developers (about_window, developers);
   adw_about_window_set_artists (about_window, artists);
+  adw_about_window_set_translator_credits (about_window,
+               /* Translators: Replace "translator-credits" with your names, one name per line */
+                                           _("translator-credits"));
   adw_about_window_set_debug_info (about_window, mobile_settings_generate_debug_info ());
 
   window = gtk_application_get_active_window (GTK_APPLICATION (self));
@@ -424,6 +429,9 @@ mobile_settings_application_init (MobileSettingsApplication *self)
                                                    g_str_equal,
                                                    g_free,
                                                    NULL);
+
+  g_io_extension_point_register (PHOSH_PLUGIN_EXTENSION_POINT_LOCKSCREEN_WIDGET_PREFS);
+  g_io_extension_point_register (PHOSH_PLUGIN_EXTENSION_POINT_QUICK_SETTING_WIDGET_PREFS);
 }
 
 
