@@ -226,7 +226,6 @@ mobile_settings_generate_debug_info (void)
       const char *key;
     } const schema[] = {
       { "sm.puri.phosh.emergency-calls", "enabled" },
-      { "sm.puri.phosh", "automatic-high-contrast" },
       { "sm.puri.phosh.plugins", "lock-screen" },
       { "org.gnome.desktop.a11y.applications", "screen-keyboard-enabled" },
       { "org.gnome.desktop.interface", "gtk-im-module" },
@@ -240,6 +239,16 @@ mobile_settings_generate_debug_info (void)
       { "org.gnome.settings-daemon.plugins.power", "sleep-inactive-ac-timeout" },
       { "org.gnome.settings-daemon.plugins.power", "sleep-inactive-ac-type" },
 
+      /* Interface related */
+      { "org.gnome.desktop.interface", "color-scheme" },
+      { "org.gnome.desktop.interface", "gtk-theme" },
+      { "org.gnome.desktop.interface", "icon-theme" },
+      { "org.gnome.desktop.interface", "show-battery-percentage" },
+      { "org.gnome.desktop.interface", "clock-format" },
+      { "org.gnome.desktop.interface", "clock-show-date" },
+      { "org.gnome.desktop.interface", "clock-show-seconds" },
+      { "org.gnome.desktop.interface", "clock-show-weekday" },
+
       /* Screen wakeup */
       { "sm.puri.phosh.notifications", "wakeup-screen-categories" },
       { "sm.puri.phosh.notifications", "wakeup-screen-triggers" },
@@ -286,12 +295,18 @@ mobile_settings_generate_debug_info (void)
     g_auto (GStrv) compatibles = gm_device_tree_get_compatibles (NULL, &err);
 
     if (compatibles && compatibles[0]) {
-      g_autofree char *compatible_str = g_strjoinv(" ", compatibles);
+      g_autofree char *compatible_str = g_strjoinv (" ", compatibles);
 
       g_string_append_printf (string, "- DT compatibles: %s\n", compatible_str);
     } else {
+      g_autofree char *modalias = NULL;
+
       g_debug ("Couldn't get device tree information: %s", err->message);
-      g_string_append (string, "Not a device tree device\n");
+
+      if (g_file_get_contents ("/sys/class/dmi/id/modalias", &modalias, NULL, NULL))
+        g_string_append_printf (string, "- DMI modalias: %s\n", modalias);
+      else
+        g_string_append_printf (string, "Could not read DMI or DT information");
     }
   }
 
